Citing ToFu: — tofu v1.1

# Citing ToFu:

An article dedicated to describing ToFu and its capacities is in preparation, in the meantime please cite this one [1], which briefly describes it and uses it to present physics results. Since this paper may not present enough details for the interested reader, please also include a url pointing to this web-based documentation.

[1] | Vezinet et al., ‘Non-monotonic growth rates of sawtooth precursors evidenced with a new method on ASDEX Upgrade’, Nuclear Fusion 56, 086001, 2016

Bibtex:

    @article{0029-5515-56-8-086001,
      author={D. Vezinet and V. Igochine and M. Weiland and Q. Yu and A. Gude and D. Meshcheriakov and M. Sertoli and the Asdex Upgrade
    Team and the EUROfusion MST1 Team},
      title={Non-monotonic growth rates of sawtooth precursors evidenced with a new method on ASDEX Upgrade},
      journal={Nuclear Fusion},
      volume={56},
      number={8},
      pages={086001},
      url={http://stacks.iop.org/0029-5515/56/i=8/a=086001},
      year={2016},
    }

## Indices and tables

- Homepage
- Index
- Module Index
- Search Page